Expression
==========

.. currentmodule:: pqp.expression

.. autoclass:: Expression
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~Expression.display
      ~Expression.to_latex

   .. rubric:: Methods Documentation

   .. automethod:: display
   .. automethod:: to_latex
